Documentation
¶
Overview ¶
Package process runs external commands while preserving structured failure information and allowing output to be captured, streamed, or both.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Failure ¶
func (*Failure) SensitiveArgs ¶
type Spec ¶
type Spec struct {
Path string
Args []string
Dir string
Env []string
Stdin io.Reader
Stdout io.Writer
Stderr io.Writer
Sensitive bool
// Clean runs the process with exactly Env as its environment, without
// inheriting the parent's (a tighter effect capability). When false, a
// non-nil Env is appended to the inherited environment.
Clean bool
}
Click to show internal directories.
Click to hide internal directories.